@@ -14,8 +14,10 @@ root_dir = os.path.dirname(__file__)
 if not os.path.exists(os.path.join(root_dir, 'Makefile.am')):
     # Running in installed mode
     APP_DATA_DIR     = os.path.join('/usr/local', 'share')
+    SHARED_DATA_DIR  = os.path.join(APP_DATA_DIR, 'gnome-games')
     BASE_DIR         = os.path.join(APP_DATA_DIR, 'glchess')
     TEXTURE_DIR      = os.path.join(BASE_DIR, 'textures')
+    SHARED_IMAGE_DIR = os.path.join(SHARED_DATA_DIR, 'pixmaps')
     UI_DIR           = BASE_DIR
     LOCALEDIR        = os.path.join(APP_DATA_DIR, 'locale')
     DATA_DIR         = os.path.expanduser('~/.gnome2/glchess/')
@@ -29,7 +31,9 @@ if not os.path.exists(os.path.join(root_dir, 'Makefile.am')):
 else:
     # Running in uninstalled mode
     APP_DATA_DIR     = os.path.join(root_dir, '../../data')
-    TEXTURE_DIR      = os.path.join(root_dir, '../../textures')
+    SHARED_DATA_DIR  = '.'
+    TEXTURE_DIR      = os.path.join(root_dir, '../../data/textures')
+    SHARED_IMAGE_DIR = os.path.join(SHARED_DATA_DIR, 'pixmaps')
     UI_DIR           = os.path.join(root_dir, '../../data')
     BASE_DIR         = os.path.join(root_dir, '../../data')
     LOCALEDIR        = os.path.join(APP_DATA_DIR, 'locale')
@@ -47,7 +51,7 @@ gettext.bindtextdomain(DOMAIN, LOCALEDIR)
 gettext.textdomain(DOMAIN)
 from gettext import gettext as _
 
-VERSION   = "2.30.2"
+VERSION   = "2.32.1"
 APPNAME   = _("glChess")
 ICON_NAME = 'gnome-glchess'
 
